'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (app, container) {
  var access = new _access2.default(container.get('auth'));
  var logger = container.get('logger');
  var adminAccess = function adminAccess(req, res, next) {
    container.get('admin-access').process(req, res, next);
  };

  app.use(logger.routerLogger);
  app.use(_bodyParser2.default.json({ strict: false, limit: '10mb' }));
  app.use(_requestParser2.default);
  app.use(_paramParser2.default);

  app.get('/-/ping', function (req, res) {
    res.send({
      message: 'ap-npm is running'
    });
  });

  app.get('/admin', adminAccess, function (req, res) {
    var route = container.get('route-admin');
    route.process(req, res);
  });

  app.get('/admin/all', adminAccess, function (req, res) {
    var route = container.get('route-admin-all');
    route.process(req, res);
  });

  app.get('/admin/config', adminAccess, function (req, res) {
    var route = container.get('route-admin-config');
    route.process(req, res);
  });

  // *** AUTH ***
  app.put('/-/user/org.couchdb.user:_rev?/:revision?', function (req, res) {
    var route = container.get('route-auth-user-login');
    route.process(req, res);
  });
  // Logout
  app.delete('/-/user/token/*', function (req, res) {
    var route = container.get('route-auth-user-logout');
    route.process(req, res);
  });
  // for "npm whoami"
  app.get('/whoami', function (req, res) {
    var route = container.get('route-auth-whoami');
    route.process(req, res);
  });
  // for "npm whoami"
  app.get('/-/whoami', function (req, res) {
    var route = container.get('route-auth-whoami');
    route.process(req, res);
  });

  // *** INSTALL ***
  // Get version of package
  app.get('/:package/:version?', access.can('access'), function (req, res) {
    var route = void 0;
    if (req.params.write) {
      route = container.get('route-package-unpublish');
    } else {
      route = container.get('route-package-get-json');
    }
    route.process(req, res);
  });
  // Request for package file data
  app.get('/:package/-/:filename', access.can('access'), function (req, res) {
    var route = container.get('route-package-get');
    route.process(req, res);
  });

  // *** DIST-TAGS ***
  app.get('/-/package/:package/dist-tags', access.can('access'), function (req, res) {
    var route = container.get('route-package-get-dist-tags');
    route.process(req, res);
  });
  app.delete('/-/package/:package/dist-tags/:tag', access.can('publish'), function (req, res) {
    var route = container.get('route-package-delete-dist-tags');
    route.process(req, res);
  });
  app.put('/-/package/:package/dist-tags/:tag', access.can('publish'), function (req, res) {
    var route = container.get('route-package-add-dist-tags');
    route.process(req, res);
  });

  // *** PUBLISH ***
  app.put('/:package/:_rev?/:revision?', access.can('publish'), function (req, res) {
    var route = container.get('route-package-publish');
    route.process(req, res);
  });

  app.delete('/:package/:_rev?/:revision?', access.can('publish'), function (req, res) {
    var route = container.get('route-package-delete');
    route.process(req, res);
  });

  // To test if ap-npm is running
  app.get('/', function (req, res) {
    if (req.url === '/' || req.url === '') {
      res.send("ap-npm is running\n");
    }
  });

  return app;
};

var _bodyParser = require('body-parser');

var _bodyParser2 = _interopRequireDefault(_bodyParser);

var _access = require('./auth/access');

var _access2 = _interopRequireDefault(_access);

var _requestParser = require('./util/request-parser');

var _requestParser2 = _interopRequireDefault(_requestParser);

var _paramParser = require('./util/param-parser');

var _paramParser2 = _interopRequireDefault(_paramParser);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }