'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (request, getPackageJson, updatePackageJson, removePackage, storageLocation) {

  return new Promise(function (resolve, reject) {
    var packageName = request.name;
    var packageScope = request.scope;
    var packageVersion = request.version;

    var packageLocation = _path2.default.join(storageLocation, packageName);
    var tarballLocation = _path2.default.join(packageLocation, packageName + packageVersion + '.tgz');

    _fs2.default.exists(packageLocation + '/package.json', function (exists) {
      if (!exists) {
        reject("Invalid request, aborting");
      }

      // location is valid
      _fs2.default.unlink(tarballLocation, function () {
        var packageJson = getPackageJson({
          name: packageName,
          scope: packageScope
        }).then(function () {
          delete packageJson.versions[packageVersion];

          // If this was the last version of the package, we can remove it completely
          if (packageJson.versions.size === 0) {
            removePackage({
              name: packageName,
              scope: packageScope
            });
            return true;
          }

          if (packageJson['dist-tags'].latest === packageVersion) {
            // need to update dist-tags
            var highestVersion = '0.0.1';
            for (var key in packageJson.versions) {
              if (_semver2.default.satisfies(key, '>' + highestVersion)) {
                highestVersion = key;
              }
            }
            packageJson['dist-tags'].latest = highestVersion;
          }
          updatePackageJson({
            name: packageName,
            scope: packageScope
          }, packageJson).then(function (result) {
            resolve(result);
          });
        });
      });
    });
  });
};

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }