'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (request, packageData, storageLocation, logger) {
  return new Promise(function (resolve) {
    var attachmentName = void 0;
    var packageName = request.name;
    var packageScope = request.scope;
    var packageInfoLocation = void 0;
    var folderPath = void 0;

    if (packageScope) {
      packageInfoLocation = _path2.default.join(storageLocation, packageScope, packageName, 'package.json');
      folderPath = _path2.default.join(storageLocation, packageScope, packageName);
    } else {
      packageInfoLocation = _path2.default.join(storageLocation, packageName, 'package.json');
      folderPath = _path2.default.join(storageLocation, packageName);
    }

    _fsExtra2.default.mkdirsSync(folderPath);
    for (var key in packageData._attachments) {
      attachmentName = key;
    }

    var newVersion = void 0;
    for (var _key in packageData.versions) {
      newVersion = _key;
    }

    var filePath = folderPath + '/' + packageName + '-' + newVersion + '.tgz';

    (0, _readJson2.default)(packageInfoLocation).then(function (packageJson) {
      packageJson.versions[newVersion] = packageData.versions[newVersion];

      var distTags = packageJson['dist-tags'];
      var newDistTags = packageData['dist-tags'];

      for (var _key2 in newDistTags) {
        distTags[_key2] = newDistTags[_key2];
      }packageJson['dist-tags'] = distTags;

      _fs2.default.writeFile(filePath, Buffer.from(packageData._attachments[attachmentName].data, 'base64'), { 'mode': '0777' }, function () {
        (0, _writeJson2.default)(packageInfoLocation, packageJson).then(function (result) {
          if (packageScope) {
            logger.info("Published new package: " + packageScope + '/' + packageName);
          } else {
            logger.info("Published new package: " + packageName);
          }
          resolve(result);
        });
      });
    });
  });
};

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _readJson = require('./read-json');

var _readJson2 = _interopRequireDefault(_readJson);

var _writeJson = require('./write-json');

var _writeJson2 = _interopRequireDefault(_writeJson);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }